@@ -32,7 +32,7 @@ from threading import Barrier, Condition, Thread
 
 from .multipart import Data
 
-__version__ = "0.9.6.5"
+__version__ = "0.9.7"
 
 BASE_URL = "https://volafile.io"
 BASE_ROOM_URL = BASE_URL + "/r/"
@@ -393,8 +393,8 @@ class Room:
                                                 file[1],  # name
                                                 file[2],  # type
                                                 file[3],  # size
-                                                # file[4],  # upload time
-                                                # file[5],  # expire time
+                                                file[4] / 1000,  # expire time
+                                                file[5] / 1000,  # upload time
                                                 file[6]['user'])
             elif data_type == "delete_file":
                 del self._files[data]
@@ -406,10 +406,10 @@ class Room:
                 change = data
                 if change['key'] == 'name':
                     self._config['title'] = change['value']
-                if change['key'] == 'file_ttl':
+                elif change['key'] == 'file_ttl':
                     self._config['ttl'] = change['value']
                 elif change['key'] == 'private':
-                    self._config['private'] = change['value'] == 'true'
+                    self._config['private'] = change['value']
                 elif change['key'] == 'motd':
                     self._config['motd'] = change['value']
                 else:
@@ -420,14 +420,11 @@ class Room:
             elif data_type == "chat_name":
                 self.user.name = data
             elif data_type == "owner":
-                self.owner = True
-            elif data_type == "time":
-                # TODO
-                pass
+                self.owner = data['owner']
             elif data_type == "update_assets":
                 # TODO
                 pass
-            elif data_type in ("subscribed", "hooks"):
+            elif data_type in ("subscribed", "hooks", "time", "login"):
                 pass
             else:
                 warnings.warn(
@@ -451,6 +448,9 @@ class Room:
         """Returns list of File objects for this room.
         Note: This will only reflect the files at the time
         this method was called."""
+        for fid in self._files.keys():
+            if self._files[fid].expired:
+                del self._files[fid]
         return list(self._files.values())
 
     def get_user_stats(self, name):
@@ -545,8 +545,7 @@ class Room:
         """Sets the room to private if given True, else sets to public"""
         if not self.owner:
             raise RuntimeError("You must own this room to do that")
-        priv = "true" if value else "false"
-        self.conn.make_call("editInfo", [{"private": priv}])
+        self.conn.make_call("editInfo", [{"private": value}])
         self._config['private'] = value
 
     @property
@@ -614,12 +613,16 @@ class File:
             name,
             file_type=None,
             size=None,
+            expire_time=None,
+            upload_time=None,
             uploader=None
     ):
         self.file_id = file_id
         self.name = name
         self.file_type = file_type
         self.size = size
+        self.expire_time = expire_time
+        self.upload_time = upload_time
         self.uploader = uploader
 
     @property
@@ -627,6 +630,16 @@ class File:
         """Gets the download url of the file"""
         return "{}/get/{}/{}".format(BASE_URL, self.file_id, self.name)
 
+    @property
+    def expired(self):
+        """Returns true if the file has expired, false otherwise"""
+        return time.time() >= self.expire_time
+
+    @property
+    def time_left(self):
+        """Returns how many seconds before this file expires"""
+        return self.expire_time - time.time()
+
     def __repr__(self):
         return ("<File({},{},{},{})>".
                 format(self.file_id, self.size, self.uploader, self.name))
@@ -641,7 +654,7 @@ class User:
         if name is None:
             self.name = ""
         else:
-            self.verify_username(name)
+            self._verify_username(name)
         self.name = name
         self.conn = conn
         self.logged_in = False
@@ -674,7 +687,7 @@ class User:
         Note: Must be logged out to change nick"""
         if self.logged_in:
             raise RuntimeError("User must be logged out")
-        self.verify_username(new_nick)
+        self._verify_username(new_nick)
 
         self.conn.make_call("command", [self.name, "nick", new_nick])
         self.name = new_nick
@@ -711,7 +724,7 @@ class User:
         if 'error' in json_resp:
             raise ValueError("Wrong password.")
 
-    def verify_username(self, username):
+    def _verify_username(self, username):
         """Raises an exception if the given username is not valid."""
         if len(username) > self._max_length or len(username) < 3:
             raise ValueError(
